@@ -68,6 +68,10 @@ class ABI_EXPORT XAP_UnixFont
 {
  public:
 
+	/*! 
+	* \todo ROB: we maybe could move to using pango attributes exclusively here 
+	* since this is unix only.
+	*/
 	enum style
 	{
 		STYLE_NORMAL = 0,
@@ -96,6 +100,9 @@ class ABI_EXPORT XAP_UnixFont
 	void					setStyle(XAP_UnixFont::style s);
 	XAP_UnixFont::style		getStyle(void) const;
 
+	PangoStyle				getPangoStyle(void) const;
+	PangoWeight				getPangoWeight(void) const;
+
 	const char * 			getFontfile(void) const;
 	const char * 			getMetricfile(void) const;
 	const encoding_pair*	loadEncodingFile(void);
@@ -130,6 +137,7 @@ class ABI_EXPORT XAP_UnixFont
 	bool doesGlyphExist(UT_UCS4Char g);
 	bool                    isSymbol(void) const;
 	bool                    isDingbat(void) const;
+
 private:
 
 	XAP_UnixFont ();
@@ -222,7 +230,7 @@ class XAP_UnixFontHandle : public GR_Font
 	float measureUnRemappedChar(const UT_UCSChar c, UT_uint32 iSize) const;
 
 	virtual bool doesGlyphExist(UT_UCS4Char g);
-        virtual bool            glyphBox(UT_UCS4Char g, UT_Rect & rec) const;
+        virtual bool            glyphBox(UT_UCS4Char g, UT_Rect & rec, GR_Graphics * pG);
 
 private:
  	XAP_UnixFontHandle();
