@@ -884,6 +884,7 @@ dcl(MENU_LABEL_EDIT_REMOVEFOOTER,"Remove Footer")
 dcl(MENU_LABEL_EDIT_CUTEMBED,"Cut Object")
 dcl(MENU_LABEL_EDIT_COPYEMBED,"Copy Object")
 dcl(MENU_LABEL_EDIT_DELETEEMBED,"Delete Object")
+dcl(MENU_LABEL_EDIT_LATEXEQUATION,"Edit Equation")
 dcl(MENU_LABEL_VIEW,"&View")
 dcl(MENU_LABEL_VIEW_NORMAL,"&Normal Layout")
 dcl(MENU_LABEL_VIEW_WEB,"&Web Layout")
@@ -1153,6 +1154,7 @@ dcl(MENU_STATUSLINE_EDIT_SELECT_FRAME,"Select the Text Box")
 dcl(MENU_STATUSLINE_EDIT_CUTEMBED,"Cut Embedded Object")
 dcl(MENU_STATUSLINE_EDIT_COPYEMBED,"Copy Embedded Object")
 dcl(MENU_STATUSLINE_EDIT_DELETEEMBED,"Delete Embedded Object")
+dcl(MENU_STATUSLINE_EDIT_LATEXEQUATION,"Edit Latex Equation")
 dcl(MENU_STATUSLINE_VIEW," ")
 dcl(MENU_STATUSLINE_VIEW_NORMAL,"Normal View")
 dcl(MENU_STATUSLINE_VIEW_WEB,"Web Layout")
