@@ -61,6 +61,7 @@ IE_Imp_OpenDocument::~IE_Imp_OpenDocument ()
     }
     
     DELETEP(m_pStreamListener);
+    DELETEP(m_pAbiData);
 } 
  
  
@@ -84,8 +85,10 @@ UT_Error IE_Imp_OpenDocument::importFile(const char * szFilename)
     if (m_pGsfInfile == NULL) {
         return UT_ERROR;
     }
-    
-    m_pStreamListener = new OD_StreamListener(getDoc(), m_pGsfInfile, &m_styles);
+
+    m_pAbiData = new OD_Abi_Data(getDoc(), m_pGsfInfile);    
+    m_pStreamListener = new OD_StreamListener(getDoc(), m_pGsfInfile, &m_styles,
+                                              *m_pAbiData);
           
     UT_Error err = UT_OK;
     
